@@ -10,6 +10,10 @@
 @CREATED    : January 3, 1996 (Peter Neelin)
 @MODIFIED   : 
  * $Log: ecattominc.c,v $
+ * Revision 6.7  2008/04/11 05:16:02  rotor
+ *  * added config.h to ecattominc
+ *  * removed minc_globdef.h from Makefile.am
+ *
  * Revision 6.6  2008/01/17 02:33:01  rotor
  *  * removed all rcsids
  *  * removed a bunch of ^L's that somehow crept in
@@ -75,6 +79,10 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
