@@ -1,22 +1,23 @@
+#if HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <limits.h>
 #include <float.h>
-
 #include <minc.h>
 #include <ParseArgv.h>
-
 #include <volume_io.h>
+
 #undef X                        /* These are used in nifti1_io */
 #undef Y
 #undef Z
 
 #include <time_stamp.h>
-
 #include "nifti1_io.h"
-
 #include "analyze75.h"
-
 #include "nifti1_local.h"
 
+
 void test_xform(mat44 m, int i, int j, int k)
 {
     double x, y, z;
@@ -98,12 +99,6 @@ main(int argc, char **argv)
 {
     /* NIFTI stuff */
     nifti_image *nii_ptr;
-    int nii_dimids[MAX_NII_DIMS];
-    int nii_dir[MAX_NII_DIMS];
-    int nii_map[MAX_NII_DIMS];
-    unsigned long nii_lens[MAX_NII_DIMS];
-    int nii_ndims;
-    int nifti_file_type;
 
     /* MINC stuff */
     int mnc_fd;                 /* MINC file descriptor */
@@ -132,7 +127,6 @@ main(int argc, char **argv)
 
     /* Other stuff */
     char out_str[1024];         /* Big string for filename */
-    char att_str[1024];         /* Big string for attribute values */
     int i;                      /* Generic loop counter the first */
     int j;                      /* Generic loop counter the second */
     char *str_ptr;              /* Generic ASCIZ string pointer */
@@ -495,7 +489,13 @@ main(int argc, char **argv)
     /* Create the group variables.
      */
     micreate_std_variable(mnc_fd, MIstudy, NC_INT, 0, NULL);
-    micreate_std_variable(mnc_fd, MIpatient, NC_INT, 0, NULL);
+    if (strlen(nii_ptr->descrip) > 0 && strlen(nii_ptr->descrip) < 79 ) {
+      int varid = micreate_std_variable(mnc_fd, MIpatient, NC_INT, 0, NULL);
+      (void) miattputstr(mnc_fd, varid, MIfull_name,
+                         nii_ptr->descrip);
+    } else {
+       micreate_std_variable(mnc_fd, MIpatient, NC_INT, 0, NULL);
+    }
     micreate_std_variable(mnc_fd, MIacquisition, NC_INT, 0, NULL);
 
     /* Create the MINC image variable.  If we can't, there is no
