@@ -10,6 +10,14 @@
 @CREATED    : August 13, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: xfminvert.c,v $
+ * Revision 6.6  2008/01/17 02:33:06  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.5  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
  * Revision 6.4  2007/08/10 11:55:35  rotor
  *  * added -clobber and -verbose to xfminvert to get it up to scratch
  *  * a bit of code cleanup (not there there is much in there!)
@@ -66,10 +74,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/xfm/xfminvert.c,v 6.4 2007/08/10 11:55:35 rotor Exp $";
-#endif
-
 #include <config.h>
 #include <stdlib.h>
 #include <stdio.h>
